<?php
namespace Ak\Gdpr\Hydrator;

use Interop\Container\ContainerInterface;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\ReflectionHydrator;
use Laminas\Hydrator\Strategy\DateTimeFormatterStrategy;
use Laminas\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu hidratora za GdprConsent entitet.
 *
 * @package Ak\Gdpr\Hydrator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gdpr
 */
final class GdprConsentHydratorFactory implements FactoryInterface
{
    /**
     * Stvara hidrator.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return HydratorInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $hydrator = new ReflectionHydrator();
        $hydrator->addStrategy('time', new DateTimeFormatterStrategy('Y-m-d H:i:s'));

        return $hydrator;
    }
}
