<?php
namespace Ak\Gdpr\Repository;

use Ak\Orm\Entity\EntityInterface;
use Ak\Orm\Repository\RepositoryInterface;
use Ak\Gdpr\Entity\GdprConsent;
use Laminas\Db\ResultSet\ResultSetInterface;
use Laminas\Db\TableGateway\AbstractTableGateway;
use Laminas\Db\TableGateway\TableGatewayInterface;
use Laminas\Hydrator\HydratorInterface;

/**
 * Repozitorij GdprConsent objekata.
 *
 * @package Ak\Gdpr\Repository
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gdpr
 */
class GdprConsentRepository implements RepositoryInterface
{
    /** @var AbstractTableGateway */
    private $table;
    /** @var HydratorInterface */
    private $hydrator;

    /**
     * Konstruktor.
     *
     * @param TableGatewayInterface $table
     * @param HydratorInterface $hydrator
     */
    public function __construct(TableGatewayInterface $table, HydratorInterface $hydrator)
    {
        $this->table = $table;
        $this->hydrator = $hydrator;
    }

    /**
     * Traži entitet po ID-u.
     *
     * @param int $id
     *
     * @return GdprConsent|null
     */
    public function find(int $id): ?EntityInterface
    {
        $rowset = $this->table->select([
            'id' => $id,
        ]);

        if (count($rowset) === 0) {
            return null;
        }

        return $this->hydrateResult($rowset)[0];
    }

    /**
     * Traži privolu po e-mail adresi.
     *
     * @param string $email
     * @return GdprConsent|null
     */
    public function findByEmail(string $email): ?GdprConsent
    {
        $rowset = $this->table->select([
            'email' => $email,
        ]);

        if (count($rowset) === 0) {
            return null;
        }

        return $this->hydrateResult($rowset)[0];
    }

    /**
     * Sprema novi entitet u bazu i vraća ga.
     *
     * @param EntityInterface $entity
     * @return EntityInterface
     */
    public function insert(EntityInterface $entity): EntityInterface
    {
        $data = $this->hydrator->extract($entity);

        $this->table->insert($data);

        $id = $this->table->getLastInsertValue();
        return $this->find($id);
    }

    private function hydrateResult(ResultSetInterface $resultSet)
    {
        $hydrated = [];

        foreach ($resultSet as $result) {
            $hydrated[] = $this->hydrator->hydrate((array) $result, new GdprConsent());
        }

        return $hydrated;
    }

    /**
     * Ažurira postojeći entitet u bazi.
     *
     * @param EntityInterface $entity
     */
    public function update(EntityInterface $entity): void
    {
        throw new \DomainException('GdprConsent entiteti se ne smiju ažurirati.');
    }

    /**
     * Briše entitet iz baze.
     *
     * @param EntityInterface $entity
     */
    public function delete(EntityInterface $entity): void
    {
        throw new \DomainException('GdprConsent entiteti se ne smiju brisati.');
    }
}
