<?php
namespace AkTest\Gdpr\Hydrator;

use Ak\Gdpr\Entity\GdprConsent;
use Ak\Test\AbstractTestCase;
use AkTest\Gdpr\TestConfigProvider;
use Laminas\Hydrator\HydratorInterface;
use Laminas\Hydrator\HydratorPluginManager;

/**
 * Class GdprConsentHydratorTest
 *
 * @package AkTest\Gdpr\Hydrator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/gdpr
 */
class GdprConsentHydratorTest extends AbstractTestCase
{
    public $configProviders = [
        TestConfigProvider::class,
    ];

    public function getHydrators(): HydratorPluginManager
    {
        $container = $this->getContainer();
        return $container->get(HydratorPluginManager::class);
    }

    public function getHydrator(string $name): HydratorInterface
    {
        $plugins = $this->getHydrators();
        return $plugins->get($name);
    }

    public function testIsRegistered()
    {
        $hydrators = $this->getHydrators();

        $this->assertTrue($hydrators->has(GdprConsent::class));
        $this->assertInstanceOf(HydratorInterface::class, $hydrators->get(GdprConsent::class));
    }

    public function testCanExchangeObjects()
    {
        $hydrator = $this->getHydrator(GdprConsent::class);
        $data = [
            'id' => 12,
            'email' => 'user@domain.tld',
            'ip' => '1.2.3.4',
            'time' => '2018-10-25 10:33:00',
        ];

        /** @var GdprConsent $consent */
        $consent = $hydrator->hydrate($data, new GdprConsent());

        $this->assertInstanceOf(GdprConsent::class, $consent);
        $this->assertEquals($data['id'], $consent->getId());
        $this->assertEquals($data['email'], $consent->getEmail());
        $this->assertEquals($data['ip'], $consent->getIp());
        $this->assertEquals($data['time'], $consent->getTime()->format('Y-m-d H:i:s'));
    }
}
